//servo inputs
  //these are the inputs from the reciever.
int SteerIn = 5;
int ThrotIn = 6;

//servo variables
  // these contain the current position of the sticks, taken from a reading of the inputs from the reciever.
int steering = 0;
int throttle = 0;
//steering points
  // these are the trigger thresholds for the switching on the steering.
int SteerMax = 1850;
int SteerMin = 1200;
//throttle points
  // these dictate the neutral band on the throttle.
int ThrotZeroPos = 1520;
int ThrotZeroRange = 19;
//Boolean indicators
  // ThrotZero goes to 1 if the throttle stick is in the neutral band.
int ThrotZero = 0;
  /* this variable is used to prevent repeat triggers when the stick is moved and held; it goes high when the 
  stick moves above the thresholds for switching on the steering, and returns when the stick is moved back
  to between the two threshold positions.*/
boolean incremented = false;
//light sequence position
  /*this stores the current position of the light sequence (0-7), and the binary value of this number is output
  on the three lights (navigation lights, spotlight, and interior lights).*/
int lights = 0;
//outputs
  /*these dictate the output pins for the LEDs to connect to. They're set how they are for ease of connection to
  the arduino.*/
int nav = 11;
int search = 12;
int inside = 13;
//this is the commented out EEPROM that breaks the programme
//#include <EEPROM.h>


void setup(){
  //pin setups
  pinMode(SteerIn, INPUT);
  pinMode(ThrotIn, INPUT);
  pinMode(nav, OUTPUT);
  pinMode(search,OUTPUT);
  pinMode(inside,OUTPUT);
  /*tests to see if the transmitter's on, by seeing if the throttle reads 0. If the tx is off when I turn the boat 
  on, it goes into the calibration routine and waits for the tx to turn on.*/
  ThrotZeroPos = pulseIn(ThrotIn, HIGH, 25000);
  if(ThrotZeroPos == 0){
    calibrate();
  }
}
void calibrate(){
  /*the calibration routine. The digitalWrites in this section are just to use as indicators of where it is in the 
  programme, and where I should move the sticks to.*/
  digitalWrite(nav,HIGH);
  //Reads the throttle position, and waits for it to be something other than 0 IE waits for the tx to turn on.
  while(ThrotZeroPos == 0){
    ThrotZeroPos = pulseIn(ThrotIn, HIGH, 25000);
  }
  digitalWrite(search,HIGH);
  /*waits 2 seconds for you to move the steering stick fully to the right, then reads this value, subtracts 15, and
  stores it as the switching threshold for the right-hand side stick movement.*/
  delay(2000);
  SteerMax = (pulseIn(SteerIn, HIGH, 25000) - 15);
  digitalWrite(search,LOW);
  digitalWrite(inside,HIGH);
  //likewise, but for the left.
  delay(2000);
  SteerMin = (pulseIn(SteerIn, HIGH,25000) + 15);
  digitalWrite(inside,LOW);
  //Here is where I intend to but the commands to store ThrotZeroPos, SteerMax & SteerMin to the EEPROM.
  digitalWrite(nav, LOW);
}

void loop(){
  //Stick readings.
  throttle = pulseIn(ThrotIn, HIGH, 25000);
  steering = pulseIn(SteerIn, HIGH, 25000);
  //Checks if the throttle is in the neutral band, and alters ThrotZero accordingly.
  if(((ThrotZeroPos+ThrotZeroRange)>throttle)&&(throttle>(ThrotZeroPos-ThrotZeroRange))){
    ThrotZero = 1;
  }
  else{
    ThrotZero = 0;
  }
  /*Checks if the stick has moved hard left while the throttle is in neutral, that the light position is
  less than 7, and that it's not a repeat trigger, and increments light position variable accordingly.*/
  if((ThrotZero==1)&&(steering>SteerMax)&&(lights<7)&&(incremented==false)){
    lights = ++lights;
    incremented = true;
  }
  //likewise, but left.
  if((ThrotZero==1)&&(steering<SteerMin)&&(lights>0)&&(incremented==false)){
    lights = --lights;
    incremented = true;  
  //resets the incremented variable when the stick drops below the tresholds, to help avoid re-triggering.
  }
  if((ThrotZero==1)&&(steering>SteerMin)&&(steering<SteerMax)){
    incremented = false;  
  }
  //binary outputs to the lights (the binary values are used as a bit mask).
  digitalWrite(nav,(lights&B001));
  digitalWrite(search,(lights&B010));
  digitalWrite(inside,(lights&B100));
}

//That's it. Thanks for looking.

